@@ -1,5 +1,5 @@
 "VSS" <-
-function (x,n=8,rotate="varimax",diagonal=FALSE,pc="pa",n.obs=NULL,plot=TRUE,title="Very Simple Structure",...)     #apply the Very Simple Structure Criterion for up to n factors on data set x
+function (x,n=8,rotate="varimax",diagonal=FALSE,fm="pa",n.obs=NULL,plot=TRUE,title="Very Simple Structure",...)     #apply the Very Simple Structure Criterion for up to n factors on data set x
  
  #x is a data matrix
   #n is the maximum number of factors to extract  (default is 8)
@@ -77,8 +77,8 @@ complexrow <- function(x,c)     #sweep out all except c loadings
  for (i in 1:n)                            #loop through 1 to the number of factors requested
  { PHI <- diag(i) 
  if(i<2) {(rotate="none")} else {rotate=old_rotate} 
-   if(!(pc=="pc")) { if ( pc=="pa") {
-   		f <- factor.pa(x,i,rotate=rotate,n.obs=n.obs,warnings=FALSE,...)   #do a factor analysis with i factors and the rotations specified in the VSS call
+   if(!(fm=="pc")) { if ( fm=="pa") {
+   		f <- factor.pa(x,i,rotate=rotate,n.obs=n.obs,warnings=FALSE,fm=fm,...)   #do a factor analysis with i factors and the rotations specified in the VSS call
  	 if (i==1)
   		 {original <- x         #just find this stuff once
 		 sqoriginal <- original*original    #squared correlations
@@ -115,7 +115,7 @@ complexrow <- function(x,c)     #sweep out all except c loadings
  	totalresid <- sum(sqresid)- diagonal * sum(diag(sqresid) )      #sum squared residuals - the main diagonal
  	fit <- 1-totalresid/totaloriginal       #fit is 1-sumsquared residuals/sumsquared original     (of off diagonal elements
  	
- 	if ((pc!="pc")) {
+ 	if ((fm !="pc")) {
  			vss.df[i,1] <- f$dof                   #degrees of freedom from the factor analysis
  			vss.df[i,2] <- f$STATISTIC             #chi square from the factor analysis
  			vss.df[i,3] <- f$PVAL                  #probability value of this complete solution
