@@ -1,6 +1,59 @@
 "factor.pa" <- 
-function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA,scores=FALSE,SMC=TRUE,missing=FALSE,impute="median", min.err = .001,digits=2,max.iter=50,symmetric=TRUE,warnings=TRUE) {
-    n <- dim(r)[2]
+function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA,scores=FALSE,SMC=TRUE,missing=FALSE,impute="median", min.err = .001,digits=2,max.iter=50,symmetric=TRUE,warnings=TRUE,fm="pa") {
+ cl <- match.call()
+ 
+ ##first some functions that are internal to factor.minres
+  #this does the ULS fitting  
+  "fit.residuals.ols" <- function(Psi,S,nf) {
+              diag(S) <- 1- Psi
+           
+              eigens <- eigen(S)
+              eigens$values[eigens$values  < .Machine$double.eps] <- 100 * .Machine$double.eps
+        #loadings <- eigen.loadings(eigens)[,1:nf]
+         if(nf >1 ) {
+         loadings <- eigens$vectors[,1:nf] %*% diag(sqrt(eigens$values[1:nf])) } else {loadings <- eigens$vectors[,1] * sqrt(eigens$values[1] ) }
+         model <- loadings %*% t(loadings)
+         residual <- (S - model)^2
+         diag(residual) <- 0
+         error <- sum(residual)
+         }
+ 
+ #this code is taken (with minor modification to make ULS) from factanal        
+ #it does the iterative calls to fit.residuals   
+     "min.res" <- function(S,nf) {
+          S.smc <- smc(S)
+          if(sum(S.smc) == nf) {start <- rep(.5,nf)}  else {start <- 1- S.smc}       
+          res <- optim(start, fit.residuals.ols, method = "L-BFGS-B", lower = .005, 
+        upper = 1, control = c(list(fnscale = 1, parscale = rep(0.01, 
+            length(start)))), nf= nf, S=S )
+    Lambda <- FAout(res$par, S, nf)
+    result <- list(loadings=Lambda,res=res)
+    }
+          
+ #these  were also taken from factanal        
+     FAout <- function(Psi, S, q) {
+        sc <- diag(1/sqrt(Psi))
+        Sstar <- sc %*% S %*% sc
+        E <- eigen(Sstar, symmetric = TRUE)
+        L <- E$vectors[, 1L:q, drop = FALSE]
+        load <- L %*% diag(sqrt(pmax(E$values[1L:q] - 1, 0)), 
+            q)
+        diag(sqrt(Psi)) %*% load
+    }
+    FAfn <- function(Psi, S, q) {
+        sc <- diag(1/sqrt(Psi))
+        Sstar <- sc %*% S %*% sc
+        E <- eigen(Sstar, symmetric = TRUE, only.values = TRUE)
+        e <- E$values[-(1L:q)]
+        e <- sum(log(e) - e) - q + nrow(S)
+        -e
+    }
+ 
+ ## now start the main function
+ if((fm !="pa") & (fm != "minres")) {message("factor method not specified correctly, principal axes used")
+   fm <- "pa" }
+   
+ n <- dim(r)[2]
     if (n!=dim(r)[1]) {  n.obs <- dim(r)[1]
                if(scores) {x.matrix <- r
              if(missing) {     #impute values 
@@ -32,9 +85,11 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA,scores=FALSE,S
     err <- comm
      i <- 1
     comm.list <- list()
+    if(fm=="pa") {
     while(err > min.err)    #iteratively replace the diagonal with our revised communality estimate
       {
         eigens <- eigen(r.mat,symmetric=symmetric)
+         eigens$values[ eigens$values < .Machine$double.eps] <-  .Machine$double.eps  #added May 14, 2009 to fix case of singular matrices
         #loadings <- eigen.loadings(eigens)[,1:nfactors]
          if(nfactors >1 ) {loadings <- eigens$vectors[,1:nfactors] %*% diag(sqrt(eigens$values[1:nfactors])) } else {loadings <- eigens$vectors[,1] * sqrt(eigens$values[1] ) }
          model <- loadings %*% t(loadings)
@@ -52,6 +107,17 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA,scores=FALSE,S
          if(i > max.iter) {if(warnings)  {message("maximum iteration exceeded")}
                 err <-0 }
        }
+       
+       }
+       
+       if(fm=="minres") { #added April 12, 2009 to do ULS fits
+       uls <- min.res(r,nfactors)
+       eigens <- eigen(r)  #used for the summary stats
+       
+       result$par <- uls$res
+       loadings <- uls$loadings
+                            }
+       
        # a weird condition that happens with the Eysenck data
        #making the matrix symmetric solves this problem
        if(!is.real(loadings)) {warning('the matrix has produced imaginary results -- proceed with caution')
@@ -70,7 +136,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA,scores=FALSE,S
    			maxi <- max(loadings)
     		if (abs(mini) > maxi) {loadings <- -loadings }
     		loadings <- as.matrix(loadings)
-    		colnames(loadings) <- "PA1"
+    		if(fm=="minres") {colnames(loadings) <- "mr1"} else {colnames(loadings) <- "PA1"}
     	} #sign of largest loading is positive
     }
     
@@ -83,33 +149,38 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA,scores=FALSE,S
      
  
     #end addition
-    	colnames(loadings) <- paste("PA",1:nfactors,sep='')
+    if(fm=="minres") {colnames(loadings) <- paste("MR",1:nfactors,sep='')	} else {colnames(loadings) <- paste("PA",1:nfactors,sep='')}
     rownames(loadings) <- rownames(r)
     loadings[loadings==0.0] <- 10^-15    #added to stop a problem with varimax if loadings are exactly 0
     
     model <- loadings %*% t(loadings)  
-    result$communality <- round(diag(model),digits)
-    result$uniquenesses <- round(diag(r-model),digits)
+   
+    #f.loadings <- loadings #used to pass them to factor.stats 
+    Phi <- NULL
     if(rotate != "none") {if (nfactors > 1) {
    
     
-   	if (rotate=="varimax") { 
-   			loadings <- varimax(loadings)$loadings 
+   	if (rotate=="varimax" | rotate=="quartimax") { 
+   			rotated <- do.call(rotate,list(loadings))
+   			loadings <- rotated$loadings
    			 Phi <- NULL} else { 
      			if ((rotate=="promax")|(rotate=="Promax")) {pro <- Promax(loadings)
      			                loadings <- pro$loadings
      			                Phi <- pro$Phi} else {
-     			if (rotate =="oblimin") {
-     				if (!require(GPArotation)) {warning("I am sorry, to do oblimin rotations requires the GPArotation package to be installed")
-     				Phi <- NULL} else { ob  <- oblimin(loadings)
+     			if (rotate == "cluster") {loadings <- varimax(loadings)$loadings           			
+								pro <- target.rot(loadings)
+     			              	loadings <- pro$loadings
+     			                Phi <- pro$Phi} else {
+     			                     
+     			if (rotate =="oblimin"| rotate=="quartimin" | rotate== "simplimax") {
+     				if (!require(GPArotation)) {warning("I am sorry, to do these rotations requires the GPArotation package to be installed")
+     				Phi <- NULL} else { ob  <- do.call(rotate,list(loadings) )
      				loadings <- ob$loadings
      				 Phi <- ob$Phi}
      		                             }
-     	               }}
+     	               }}}
      	  
      }}
-        #just in case the rotation changes the order of the factors, sort them
-        #added October 30, 2008
        
    if(nfactors >1) {
     ev.rotated <- diag(t(loadings) %*% loadings)
@@ -120,40 +191,20 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA,scores=FALSE,S
     class(loadings) <- "loadings"
     if(nfactors < 1) nfactors <- n
    
-    residual<- r - model
-    r2 <- sum(r*r)
-    rstar2 <- sum(residual*residual)
-    if (residuals) {result$residual <- round(residual,digits)}
-  
-    r2.off <- r
-    diag(r2.off) <- 0
-    r2.off <- sum(r2.off^2)
-    diag(residual) <- 0
-    rstar.off <- sum(residual^2)
-    result$fit <- round(1-rstar2/r2,digits)
-    result$fit.off <- round(1-rstar.off/r2.off,digits)
-    result$values <- round(eigens$values,digits)
-  
-    diag(model) <- 1   
-    model.inv <- solve(model)
-    m.inv.r <- model.inv %*% r
-    if(is.na(n.obs)) {result$n.obs=NA
-    			
-    			result$PVAL=NA} else {result$n.obs=n.obs}
-    result$dof <-  n * (n-1)/2 - n * nfactors + (nfactors *(nfactors-1)/2)
-    result$objective <- sum(diag((m.inv.r))) - log(det(m.inv.r)) -n 
-    result$criteria <- c("objective"=result$objective,NA,NA)
-    if (!is.na(n.obs)) {result$STATISTIC <-  result$objective * ((n.obs-1) -(2 * n + 5)/6 -(2*nfactors)/3)
-          if(!is.nan(result$STATISTIC))if (result$STATISTIC <0) {result$STATISTIC <- 0}  
-   			if (result$dof > 0) {result$PVAL <- pchisq(result$STATISTIC, result$dof, lower.tail = FALSE)} else result$PVAL <- NA}
-    result$loadings <- round(loadings,digits)
-
+    result <- factor.stats(r,loadings,Phi,n.obs)   #do stats as a subroutine common to several functions
+    
+    result$rotate  <- rotate
+    result$loadings <- loadings
+    result$values <- eigens$values
+    result$communality <- round(diag(model),digits)
+    result$uniquenesses <- round(diag(r-model),digits)
     if(!is.null(Phi)) {result$Phi <- Phi}
-    result$communality.iterations <- round(unlist(comm.list),digits)
+    if(fm=="pa") result$communality.iterations <- round(unlist(comm.list),digits)
     
     if(scores) {result$scores <- factor.scores(x.matrix,loadings) }
     result$factors <- nfactors 
     result$fn <- "factor.pa"
+    result$Call <- cl
     class(result) <- c("psych", "fa")
     return(result) }
     
@@ -163,7 +214,17 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA,scores=FALSE,S
  "factor.scores" <- function(x,f) {
      if(!is.matrix(f)) f <- loadings(f)
      r <- cor(x,use="pairwise")   #find the correlation matrix from the data
-     w <- solve(r,f)   #these are the factor weights
+     w <- try(solve(r,f),silent=TRUE )  #these are the factor weights
+     if(class(w)=="try-error") {warning("correlation matrix is singular, approximation used")
+     ev <- eigen(r)
+     ev$values[ev$values < .Machine$double.eps] <- 100 * .Machine$double.eps
+       r <- ev$vectors %*% diag(ev$values) %*% t(ev$vectors)
+       diag(r)  <- 1
+      w <- solve(r,f)}
      scores <- scale(x) %*% w    #standardize the data before doing the regression
      return(scores) }
-     #how to treat missing data?  see score.item
\ No newline at end of file
+     #how to treat missing data?  see score.item
+     
+   
+    
+  
\ No newline at end of file
